package api

import (
	"fmt"
	"model/msp"
	"mspkey/fc"
	"mspkey/info"
	"net/http"

	"github.com/gin-gonic/gin"
)

//注册用户
func ReMake(c *gin.Context) {

	// {"Name":"admin","Pwd":"xxxxx","Mail":"123456@qq.com","Tp":"1/2"}  1作者 2用户

	type st struct {
		Name string `form:"Name" json:"Name" binding:"required"`
		Pwd  string `form:"Pwd" json:"Pwd" binding:"required"`
		QQ   string `form:"QQ" json:"QQ" binding:"required"`
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	fmt.Println(p)
	if fc.ReMake(p.Name, p.Pwd, p.QQ) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "注册成功",
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "注册失败",
		})

	}

}

//用户登录
func MakeLogin(c *gin.Context) {
	type st struct {
		Name string `form:"Name" json:"Name" binding:"required"`
		Pwd  string `form:"Pwd" json:"Pwd" binding:"required"`
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	token := fc.MakeLogin(p.Name, p.Pwd, c)
	if token != "" {
		c.JSON(http.StatusOK, gin.H{
			"code":  "1",
			"msg":   "登录成功",
			"token": token,
		})

		return
	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "登录失败",
		})
		return
	}

}

//添加软件接口
func Addsof(c *gin.Context) {

	token := c.Query("token")
	mode := c.Query("mode")
	if token == "" || mode == "" {
		fmt.Println("0000000")
		return
	}

	to := new(msp.Token)
	t, name := to.CKToken(token, info.Key)
	if t == 0 {
		c.String(400, "token过期请重新登录")
		return
	}
	if !fc.IsMake(name) {
		c.String(400, "你不是作者不能添加")
		return
	}

	var p info.Sof

	err := c.BindJSON(&p)
	if err != nil {
		return
	}

	p.Make = name
	if fc.Addsof(&p, mode) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
		})
		return
	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "2",
			"msg":  "失败",
		})
		return
	}

}

//删除软件接口
func Delsof(c *gin.Context) {

	type st struct {
		Token string
		Id    string
		Skey  string
	}
	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)
	t, name := to.CKToken(p.Token, info.Key)

	if t == 0 && !fc.IsMake(name) {

		c.String(400, "参数错误")

		return
	}

	if fc.Delsof(name, p.Skey, p.Id) {

		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "删除成功",
		})
		return

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "删除失败",
		})

		return

	}

}

//获取软件列表接口
func Getsoflist(c *gin.Context) {

	type st struct {
		Token string
	}
	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)
	t, name := to.CKToken(p.Token, info.Key)

	if t == 0 || !fc.IsMake(name) {
		return
	}

	var data []info.Sof

	if fc.Getsoflist(name, &data) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
			"data": data,
		})
		return

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})
		return
	}

}

//生成卡密
func Addcars(c *gin.Context) {

	type st struct {
		Token string
		Num   int
		Data  info.Car
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)

	t, name := to.CKToken(p.Token, info.Key)

	if t == 0 || !fc.IsMake(name) {
		c.String(400, "参数错误66666")
		return
	}

	if fc.Addcars(name, p.Num, &p.Data) {

		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
		})

		return

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})
		return
	}

}

//获取卡密列表
func Getcarlist(c *gin.Context) {

	type st struct {
		Token string
		Skip  string
		Mode  string
		Skey  string
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	if p.Token == "" || p.Skey == "" || p.Skip == "" || p.Mode == "" {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)
	t, name := to.CKToken(p.Token, info.Key)
	if t == 0 || name == "" {
		c.String(400, "token错误或过期")
		return
	}

	if !fc.IsMake(name) {
		return
	}
	var list []info.Car
	if fc.Getcarlist(name, p.Skip, p.Mode, p.Skey, &list) {

		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
			"data": list,
		})

	} else {

		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}

//获取用户列表
func Getuserlist(c *gin.Context) {
	type st struct {
		Token string
		Skey  string
		Mode  string
		Skip  string
	}
	var p st

	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	fmt.Println(p)
	to := new(msp.Token)
	t, name := to.CKToken(p.Token, info.Key)

	if t == 0 {
		c.String(400, "token已过期")
		return
	}

	if !fc.IsMake(name) {
		c.String(400, "你不是作者")
		return
	}

	var users []info.User
	if fc.Getuserlist(name, p.Skey, p.Mode, p.Skip, &users) {

		for i := 0; i < len(users); i++ {
			users[i].Pwd = "********"

		}

		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
			"data": users,
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}

//获取单用户
func GetUser(c *gin.Context) {

	type st struct {
		Token string `form:"Token" json:"Token" binding:"required"`
		Name  string `form:"Name" json:"Name" binding:"required"`
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)
	t, makename := to.CKToken(p.Token, info.Key)
	if t == 0 {
		c.String(400, "token无效或过期")
		return
	}

	if !fc.IsMake(makename) {
		c.String(400, "你不是作者,没有权限")
		return
	}
	var user info.User
	if fc.GetUser(makename, p.Name, &user) {

		user.Pwd = "********"
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
			"data": user,
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}

//修改用户状态
func SetUserSt(c *gin.Context) {

	// {"Token":"xxxxxxxxxx","Name":"xxxxxxxx","State":"0"} 状态  0离线 1在线 -1被禁用
	type st struct {
		Token string `form:"Token" json:"Token" binding:"required"`
		Name  string `form:"Name" json:"Name" binding:"required"`
		State string `form:"State" json:"State" binding:"required"`
	}
	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)
	t, makeName := to.CKToken(p.Token, info.Key)

	if t == 0 {
		c.String(400, "无效token")
		return
	}
	if !fc.IsMake(makeName) {
		c.String(400, "没有权限")
		return
	}

	if !fc.IsName(p.Name, "2") {
		c.String(400, "用户不存在")
		return
	}

	if fc.SetUserSt(makeName, p.Name, p.State) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}

//修改作者密码
func SetMakePwd(c *gin.Context) {

	type st struct {
		Name   string `form:"Name" json:"Name" binding:"required"`
		OPwd   string `form:"OPwd" json:"OPwd" binding:"required"`
		NewPwd string `form:"NewPwd" json:"NewPwd" binding:"required"`
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	if !fc.IsMake(p.Name) {
		return
	}

	if p.OPwd == p.NewPwd {
		c.String(400, "新密码不能与旧密码一致")
		return
	}

	if fc.SetMakePwd(p.Name, p.OPwd, p.NewPwd) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}

//获取作者个人信息
func GetMakeInfo(c *gin.Context) {
	type st struct {
		Token string `form:"Token" json:"Token" binding:"required"`
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)
	t, MakeName := to.CKToken(p.Token, info.Key)

	if t == 0 {
		c.String(400, "无效token")
		return
	}

	if !fc.IsMake(MakeName) {
		c.String(400, "权限不足")
		return
	}
	var makeuser info.Make
	if fc.GetMakeInfo(MakeName, &makeuser) {
		makeuser.Pwd = "********"
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
			"data": makeuser,
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}
