package api

import (
	"model/msp"
	"mspkey/fc"
	"mspkey/info"
	"net/http"

	"github.com/gin-gonic/gin"
)

//注册用户
func ReUser(c *gin.Context) {

	type st struct {
		Name   string `form:"Name" json:"Name" binding:"required"`
		Pwd    string `form:"Pwd" json:"Pwd" binding:"required"`
		QQ     string `form:"QQ" json:"QQ" binding:"required"`
		Serial string `form:"Serial" json:"Serial" binding:"required"`
		Facid  string `form:"Facid" json:"Facid" binding:"required"`
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	var uer info.User
	uer.Name = p.Name
	uer.Pwd = p.Pwd
	uer.QQ = p.QQ
	uer.Facid = p.Facid

	if fc.ReUser(&uer, p.Serial) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}

//用户登录
func UserLogin(c *gin.Context) {

	type st struct {
		Name  string `form:"Name" json:"Name" binding:"required"`
		Pwd   string `form:"Pwd" json:"Pwd" binding:"required"`
		Facid string `form:"Facid" json:"Facid" binding:"required"`
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}
	if fc.IsName(p.Name, "2") {
		ok, token := fc.UserLogin(p.Name, p.Pwd, p.Facid, c.ClientIP())

		if ok {
			c.JSON(http.StatusOK, gin.H{
				"code":  "1",
				"msg":   "成功",
				"token": token,
			})
		} else {
			c.JSON(http.StatusOK, gin.H{
				"code": "0",
				"msg":  "失败",
			})

		}

	} else {
		c.String(400, "用户不存在")
	}

}

//用户下线
func UserDown(c *gin.Context) {
	type st struct {
		Token string `form:"Token" json:"Token" binding:"required"`
	}
	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)
	t, name := to.CKToken(p.Token, info.Key)
	if t == 0 {
		c.String(400, "无效token")
		return
	}
	if !fc.IsName(name, "2") {
		c.String(400, "你不是客户")
		return
	}

	if fc.UserDown(name) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}

//发送心跳包和设备id
func SendH(c *gin.Context) {
	type st struct {
		Token string `form:"Token" json:"Token" binding:"required"`
		Facid string `form:"Facid" json:"Facid" binding:"required"`
	}

	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	to := new(msp.Token)
	t, name := to.CKToken(p.Token, info.Key)
	if t == 0 {
		c.String(400, "无效token")
		return
	}

	if fc.SendH(name, p.Facid, c.ClientIP()) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}
}

//获取用户信息
func GetUserInfo(c *gin.Context) {
	type st struct {
		Token string
		Facid string
	}
	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}
	to := new(msp.Token)
	t, name := to.CKToken(p.Token, info.Key)
	if t == 0 {
		c.String(400, "无效token")
		return
	}
	var user info.User
	ok := fc.GetUserInfo(name, &user)
	user.Pwd = "******"
	if ok {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
			"data": user,
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}

}

//修改密码
func SetUserPwd(c *gin.Context) {
	type st struct {
		Name   string `form:"Name" json:"Name" binding:"required"`
		OPwd   string `form:"OPwd" json:"OPwd" binding:"required"`
		NewPwd string `form:"NewPwd" json:"NewPwd" binding:"required"`
	}
	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}

	if !fc.IsName(p.Name, "2") {
		c.String(400, "该用户不存在")
		return
	}

	if fc.SetUserPwd(p.Name, p.OPwd, p.NewPwd) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}
}

//获取软件信息
func GetSofInfo(c *gin.Context) {

	type st struct {
		Token string `form:"Token" json:"Token" binding:"required"`
	}
	var p st
	err := c.BindJSON(&p)
	if err != nil {
		c.String(400, "参数错误")
		return
	}
	to := new(msp.Token)
	t, name := to.CKToken(p.Token, info.Key)
	if t == 0 {
		c.String(400, "无效token")
		return
	}
	var sof info.Sof
	if fc.GetSofInfo(name, &sof) {
		c.JSON(http.StatusOK, gin.H{
			"code": "1",
			"msg":  "成功",
			"data": sof,
		})

	} else {
		c.JSON(http.StatusOK, gin.H{
			"code": "0",
			"msg":  "失败",
		})

	}
}
