package fc

import (
	"model/msp"
	"mspkey/info"
	"time"
)

func CreatTable() {
	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	//创建作者表
	sql.DB.CreateTable(&info.Make{})
	//创建用户表
	sql.DB.CreateTable(&info.User{})
	//创建软件表
	sql.DB.CreateTable(&info.Sof{})
	//创建卡密表
	sql.DB.CreateTable(&info.Car{})
	//创建网络验证信息表
	sql.DB.CreateTable(&info.MspKey{})
	//默认作者

}

//判断用户是否存在 存在为真 1作者 2用户
func IsName(name, mode string) bool {
	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	num := 0

	switch mode {
	case "1":
		//作者
		sql.DB.Model(&info.Make{}).Where("`Name` = ?", name).Count(&num)
		if num > 0 {
			return true
		}
		return false
	case "2":
		//客户
		sql.DB.Model(&info.User{}).Where("`Name` = ?", name).Count(&num)
		if num > 0 {
			return true
		}
		return false
	default:
		return false
	}

}

//查询卡密 存在为真
func IsCar(Serial string, car *info.Car) bool {
	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	num := 0
	sql.DB.Where("`Serial` = ?", Serial).First(&car).Count(&num)
	if num > 0 {
		return true
	}
	return false
}

//用户充值
func Recharge(Serial, UserName string) bool {

	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()

	//查询卡密是否存在 并且有效
	var car info.Car
	num := 0
	sql.DB.Model(&info.Car{}).Where("`Serial` = ?", Serial).First(&car).Count(&num)
	if num == 0 {
		return false
	}
	if car.State == "1" {
		return false
	}

	//判断用户是否存在 且绑定的软件与卡密一致
	var us info.User
	usnum := 0
	sql.DB.Model(&info.User{}).Where("`Name` = ?", UserName).First(&us).Count(&usnum)
	if usnum == 0 {
		return false
	}

	if car.Skey != us.Skey {
		return false
	}
	//开始充值事物
	tx := sql.DB.Begin()
	//修改卡密为已使用
	err := tx.Model(&info.Car{}).Where("`Serial` = ?", Serial).Update(&info.Car{
		State:   "1",
		Use:     UserName,
		Usetime: time.Now(),
	}).Error
	//修改用户到期时间
	var t time.Duration
	switch car.Tp {
	case 0:
		//小时卡
		t = 1 * time.Hour
	case 1:
		//天卡
		t = 24 * time.Hour
	case 2:
		//周卡
		t = 7 * 24 * time.Hour
	case 3:
		//月卡
		t = 30 * 24 * time.Hour
	default:
		return false
	}

	//判断用户是否过期
	if us.Endtime.Unix() < time.Now().Unix() {
		//已过期
		err = tx.Model(&info.User{}).Where("`Name` = ?", UserName).Update(&info.User{
			Endtime: time.Now().Add(t),
		}).Error

	} else {
		//没有过期
		err = tx.Model(&info.User{}).Where("`Name` = ?", UserName).Update(&info.User{
			Endtime: us.Endtime.Add(t),
		}).Error

	}

	//修改软件金额
	var sof info.Sof
	err = tx.Model(&info.Sof{}).Where("`Skey` = ?", car.Skey).First(&sof).Error
	err = tx.Model(&info.Sof{}).Where("`Skey` = ?", car.Skey).Update(&info.Sof{
		Money: sof.Money + car.Money,
	}).Error

	if err != nil {
		tx.Callback()
		return false
	}
	tx.Commit()
	return true
}
