package fc

import (
	"model/msp"
	"mspkey/info"
	"time"
)

//注册用户 真为成功
func ReUser(p *info.User, Serial string) bool {

	if IsName(p.Name, "2") {
		return false
	}

	//查询卡密是否存在
	var car info.Car
	if !IsCar(Serial, &car) {
		return false
	}

	//查询卡密是否有效
	if car.State == "1" {
		return false
	}

	//判断卡密类型
	var t time.Duration
	switch car.Tp {
	case 0:
		//小时卡
		t = 1 * time.Hour
	case 1:
		//天卡
		t = 24 * time.Hour
	case 2:
		//周卡
		t = 7 * 24 * time.Hour
	case 3:
		//月卡
		t = 30 * 24 * time.Hour
	default:
		return false
	}

	p.Intl = 10
	p.State = "0"
	p.Endtime = time.Now().Add(t)
	p.Sname = car.Sname
	p.Skey = car.Skey
	p.Mame = car.Name
	p.Retime = time.Now()
	//开始注册事物
	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	tx := sql.DB.Begin()

	//更改卡状态
	err := tx.Model(&info.Car{}).Where("`Serial` = ?", Serial).Update(&info.Car{State: "1", Use: p.Name, Usetime: time.Now()}).Error
	//注册用户
	err = tx.Create(&p).Error
	//修改软件状态
	var so info.Sof
	err = tx.Model(&info.Sof{}).Where("`Sname` = ? and `Skey` = ?", car.Sname, car.Skey).First(&so).Error
	err = tx.Model(&info.Sof{}).Where("`Sname` = ? and `Skey` = ?", car.Sname, car.Skey).Update(&info.Sof{
		Money:   so.Money + car.Money,
		Usernum: so.Usernum + 1,
	}).Error

	if err != nil {
		tx.Callback()
		return false
	}
	tx.Commit()

	return true
}

//用户登录
func UserLogin(Name, Pwd, Faci, ip string) (bool, string) {

	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	//查询用户是否  展示不验证设备
	var p info.User
	num := 0
	sql.DB.Model(&info.User{}).Where("`Name` = ? and `Pwd` = ?", Name, Pwd).First(&p).Count(&num)
	if num == 0 {
		return false, ""
	}

	//判断用户是否被禁用
	if p.State == "-1" {
		return false, ""
	}

	//判断用户是否到期

	if p.Endtime.Unix() < time.Now().Unix() {

		return false, ""
	}
	//修改状态为在线
	err := sql.DB.Model(&info.User{}).Where("`Name` = ? and `Pwd` = ?", Name, Pwd).Update(&info.User{
		State:     "1",
		Logintime: time.Now(),
		Loginip:   ip,
		Facid:     Faci,
	}).Error

	if err != nil {
		return false, ""
	}

	//返回took
	to := new(msp.Token)
	t := time.Minute * 10
	token := to.GetToken(Name, info.Key, t)
	return true, token

}

//用户下线
func UserDown(name string) bool {

	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	err := sql.DB.Model(&info.User{}).Where("`Name` = ?", name).Update(&info.User{
		State: "0",
		Htnum: 0,
	}).Error
	if err != nil {

		return false
	}
	return true

}

//发送心跳包
func SendH(name, facid, ip string) bool {
	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	var p info.User
	num := 0
	sql.DB.Model(&info.User{}).Where("`Name` = ?", name).First(&p).Count(&num)
	if num == 0 {
		return false
	}

	if p.Loginip != ip {
		return false
	}
	if p.Facid != facid {
		return false
	}

	var ht = p.Htnum + 1

	err := sql.DB.Model(&info.User{}).Where("`Name` = ?", name).Update(&info.User{
		Htnum: ht,
	}).Error
	if err != nil {

		return false
	}
	return true
}

//获取个人信息
func GetUserInfo(name string, user *info.User) bool {

	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	num := 0
	sql.DB.Model(&info.User{}).Where("`Name` = ?", name).First(&user).Count(&num)
	if num > 0 {
		return true
	}
	return false

}

//修改密码
func SetUserPwd(Name, OPwd, NewPwd string) bool {

	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	var p info.User
	num := 0
	sql.DB.Model(&info.User{}).Where("`Name` = ? and `Pwd` = ?", Name, OPwd).First(&p).Count(&num)
	if num == 0 {
		return false
	}
	err := sql.DB.Model(&info.User{}).Where("`Name` = ? and `Pwd` = ?", Name, OPwd).Update(&info.User{
		Pwd: NewPwd,
	}).Error
	if err != nil {
		return false
	}
	return true

}

//获取软件信息
func GetSofInfo(Name string, Sof *info.Sof) bool {

	sql := new(msp.DB)
	sql.Init(info.Mysqlurl)
	defer sql.DB.Close()
	//先查询用户表获取用户信息
	var p info.User
	num := 0
	sql.DB.Model(&info.User{}).Where("`Name` = ?", Name).First(&p).Count(&num)
	if num == 0 {
		return false
	}
	num1 := 0
	sql.DB.Model(&info.Sof{}).Where("`Sname` = ? and `Skey` = ?", p.Sname, p.Skey).First(&Sof).Count(&num1)

	if num == 0 {
		return false
	}

	return true
}
